# nbwatch
Preview IPython notebooks in your browser.

# Installation
nbwatch can be installed from [PyPI](https://pypi.org/project/nbwatch/):
```shell
pip install tapmap
```
Or with [poetry](https://poetry.eustace.io):
```shell
git clone https://github.com/AnonGuy/nbwatch
cd nbwatch
poetry install
```
